@@ -1,6 +1,6 @@
   /*
 
-  knetfilter v. 3.0.2
+  knetfilter v. 3.1.2
 
   Copyright (C) 2002 Luigi Genoni
   		     venom@sns.it
@@ -281,6 +281,7 @@ public slots:
   void setmanglepolRules(KProcess *, char *, int);
   void mangleprotocolActivated(int);
   void manglechainActivated(int);
+  void mangleecnflagsActivated(int);
   void mangletosActivated(int);
   void manglepolchainActivated(int);
   void mangleactionActivated(int);
@@ -428,6 +429,7 @@ private:
   QComboBox *mangleprotocol;
   QComboBox *mangleaction;
   QComboBox *mangletos;
+  QComboBox *mangleecnflags;
   QComboBox *loglevel;
   QComboBox *nmapoptions;
   QComboBox *nmapoptions_icmp;
@@ -507,6 +509,9 @@ private:
   char *mangleSyn;
   char *nmapopt;
   char *nmapopt_icmp;
+  char *mangleecnflagChoice;
+  char *mangleecnParam;
+  char *hasmangleEcn;
   char *logLevel;
   char *log1;
   char *log2;
