@@ -9,9 +9,9 @@
  */
 /*
 
-  knetfilter v 3.0.2
+  knetfilter v 3.3.1
 
-  Copyright (C) 2002 Luigi Genoni
+  Copyright (C) 2004 Luigi Genoni
                      venom@sns.it
 */
 
@@ -47,8 +47,10 @@ struct procfile
 procfile pf[NUM_PROC_FILES] = 
 	{
 	 {NULL, "/proc/net/ip_conntrack", "r", NULL, 
-		"You have not supported netfilter in your kernel.\n"
-		"Please recompile the kernel and netfilter tools.\n", 1},
+		"You don't have ip_conntrack and ipt_conntrack modules\n"
+	        "loaded in your kernel. You won't be able to use \n"
+	        "all knetfilter features. Please load them or \n" 
+		"recompile the kernel and netfilter tools.\n", 0},
 	 {NULL, "/proc/sys/net/ipv4/ip_forward", "r+", "1", 
 		"Could not write to /proc/sys/net/ipv4/ip_forward.\n", 1},
 	 {NULL, "/proc/sys/net/ipv4/ip_dynaddr", "r+", "1",
@@ -102,12 +104,14 @@ int initialize()
 	FILE *sbin3;
 	FILE *sbin4;
 	FILE *sbin5;
+	FILE *sbin6;
 
 	sbin = fopen("/usr/bin/iptables", "r");
 	sbin2 = fopen("/usr/local/bin/iptables", "r");
 	sbin3 = fopen("/sbin/iptables", "r");
 	sbin4 = fopen("/usr/sbin/iptables", "r");
 	sbin5 = fopen("/usr/local/sbin/iptables", "r");
+	sbin6 = fopen("/bin/iptables", "r");
 
 	/*
 	 * check if user is root.
@@ -121,7 +125,7 @@ int initialize()
 	/*
 	 * check if we have iptables.
  	 */
-	else if(sbin==NULL && sbin2==NULL && sbin3==NULL && sbin4==NULL && sbin5==NULL) 
+	else if(sbin==NULL && sbin2==NULL && sbin3==NULL && sbin4==NULL && sbin5==NULL && sbin6==NULL) 
 	{
 		QMessageBox::critical(0, "Error",
 			"Couldn't locate iptables. Please install\n"
@@ -131,6 +135,7 @@ int initialize()
 		fclose(sbin3);
 		fclose(sbin4);
 		fclose(sbin5);
+		fclose(sbin6);
 		exit(0);
 	}
 
