@@ -1,9 +1,9 @@
   /*
 
-  knetfilter v 2.1.2
+  knetfilter v 3.0.2
 
-  Copyright (C) 2001 Luigi Genoni
-                     venom@DarkStar.sns.it
+  Copyright (C) 2002 Luigi Genoni
+                     venom@sns.it
   */
 
 
@@ -245,7 +245,7 @@ void knetfilter::markRules() {
      
       
 	markList->show();
-	setView(markList);
+	setCentralWidget(markList);
       }
     else
       
