@@ -1,8 +1,8 @@
   /*
 
-  knetfilter v 3.1.1
+  knetfilter v 3.1.3
 
-  Copyright (C) 2002 Luigi Genoni
+  Copyright (C) 2003 Luigi Genoni
   		     venom@sns.it
   */
   
@@ -336,7 +336,7 @@ void knetfilter::iptablesRules() {
       }
       else {
 	QPushButton *btnTraff = new QPushButton(masqList);
-	btnTraff->setText("Masq Entries");
+	btnTraff->setText("NAT Entries");
 	btnTraff->setFixedHeight(btnTraff->sizeHint().height());
 	connect(btnTraff,SIGNAL(clicked()), this, SLOT(startmasqEntries()));
 	grid->addWidget(btnTraff,7,1);
