@@ -1,8 +1,8 @@
   /*
 
-  knetfilter v 3.0.2
+  knetfilter v 3.3.0
 
-  Copyright (C) 2002 Luigi Genoni
+  Copyright (C) 2004 Luigi Genoni
   		     venom@sns.it
   */
   
@@ -147,31 +147,38 @@ void knetfilter::startnatRules() {
 				    "You have to supply a redirection address\nfor Destination NAT and Source NAT");
 	    }
 	  else
-	    {
-	      if(firstport.length()==0) //fp=n
-		{
-		  if(secondport.length()==0) //fp=n sp=n
-		    {
-		      addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "-d" << secondnetwork << "-j" << natchainResult << "--to" << redirection;
-		    }
-		  else //fp=n sp!=n
-		    {
-		      addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "-d" << secondnetwork << "--destination-port" << secondport << "-j" << natchainResult << "--to" << redirection;
-		    }
-		}      
-	      if(firstport.length()!=0) //fp!=n
-		{
-		  if(secondport.length()!=0) //fp!=n sp!=n
-		    {
-		      addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "--source-port" << firstport << "-d" << secondnetwork << "--destination-port" << secondport << "-j" << natchainResult << "--to" << redirection;
-		    }
-		  else //fp!=n sp=n 
-		    {
-		      addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "--source-port" << firstport << "-d" << secondnetwork << "-j" << natchainResult << "--to" << redirection; 
-		    }
-		}
-	    }	  
+	    if(strcmp(natchainResult,"SAME")==0 && thirdport.length()!=0)
+	      { 
+	      QMessageBox::critical(0, "Error",
+				    "SAME target doesn't want a redirection port");
+	      }
+	    else
+	      {
+		if(firstport.length()==0) //fp=n
+		  {
+		    if(secondport.length()==0) //fp=n sp=n
+		      {
+			addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "-d" << secondnetwork << "-j" << natchainResult << "--to" << redirection;
+		      }
+		    else //fp=n sp!=n
+		      {
+			addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "-d" << secondnetwork << "--destination-port" << secondport << "-j" << natchainResult << "--to" << redirection;
+		      }
+		  }      
+		if(firstport.length()!=0) //fp!=n
+		  {
+		    if(secondport.length()!=0) //fp!=n sp!=n
+		      {
+			addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "--source-port" << firstport << "-d" << secondnetwork << "--destination-port" << secondport << "-j" << natchainResult << "--to" << redirection;
+		      }
+		    else //fp!=n sp=n 
+		      {
+			addredirect << "iptables" << "-t" << "nat" << natruleaction << natchainChoice << natrulepos << "-p" << natprotocolChoice << "-s" << firstnetwork << "--source-port" << firstport << "-d" << secondnetwork << "-j" << natchainResult << "--to" << redirection; 
+		      }
+		  }
+	      }	
 	}
+
       bool success=addredirect.start();
       if(success)
 	statusbar->message(i18n("Running..."), 2000);
@@ -411,6 +418,8 @@ void knetfilter::natRules() {
       natchain->insertItem("DNAT PREROUTING");
       natchain->insertItem("DNAT OUTPUT");
       natchain->insertItem("SNAT POSTROUTING");
+      natchain->insertItem("SAME PREROUTING");
+      natchain->insertItem("SAME POSTROUTING");
       natchain->insertItem("REDIRECT");
       natchain->insertItem("REDIRECT OUTPUT");
       natchain->setFixedHeight(natchain->sizeHint().height());
@@ -565,9 +574,17 @@ void knetfilter::natchainActivated(int index) {
     break;
   case 3:
     natchainChoice = "PREROUTING";
-    natchainResult = "REDIRECT";
+    natchainResult = "SAME"; 
     break;
   case 4:
+    natchainChoice = "POSTROUTING";
+    natchainResult = "SAME"; 
+    break;
+  case 5:
+    natchainChoice = "PREROUTING";
+    natchainResult = "REDIRECT";
+    break;
+  case 6:
     natchainChoice = "OUTPUT";
     natchainResult = "REDIRECT";
     break;
