@@ -1,9 +1,9 @@
   /*
 
-  knetfilter v 2.1.3
+  knetfilter v 3.0.2
 
-  Copyright (C) 2001 Luigi Genoni
-  		     venom@DarkStar.sns.it
+  Copyright (C) 2002 Luigi Genoni
+  		     venom@sns.it
   */
   
 
@@ -90,38 +90,62 @@ void knetfilter::addRule() {
 
     if(sport.length()==0 && dport.length()==0) 
       QMessageBox::critical(0, "Error",
-    			"You have to supply a source or destination port number.\n");
+			    "You have to supply a source or destination port number.\n");
     else if(!strcmp(ip,"Couldn't probe") && !strcmp(netmask,"Couldn't probe"))
       QMessageBox::critical(0, "Error",
-      			"Not a valid IP address and Netmask address.\n");
+			    "Not a valid IP address and Netmask address.\n");
     else if(!strcmp(ip,"Couldn't probe"))
       QMessageBox::critical(0, "Error",
-      			"Not a valid IP address.\n");
+			    "Not a valid IP address.\n");
     else if(!strcmp(netmask,"Couldn't probe"))
       QMessageBox::critical(0, "Error",
-      			"Not a valid netmask address.\n");
+			    "Not a valid netmask address.\n");
     else {
       if (strcmp("nostate",stateChoice)==0)
-      {
-	if (dport.length()==0)
-	  {
-	    addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	    addp2 << "iptables" << ruleaction << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	  }
-	else
-	  {
-	    if (sport.length()==0)
-	      {
-		addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	      }
-	    else
-	      {
-		addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	      }
-	  }
-      }
+	{
+	  if (strcmp("ecn",hasEcn)==0)
+	    {
+	      if (dport.length()==0)
+		{
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  addp2 << "iptables" << ruleaction << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		}
+	      else
+		{
+		  if (sport.length()==0)
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}
+	    }
+	  else
+	    {
+	      if (dport.length()==0)
+		{
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  addp2 << "iptables" << ruleaction << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		}
+	      else
+		{
+		  if (sport.length()==0)
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}
+	    }
+	}
       else
 	{
 	  if (strcmp("unclean",stateChoice)==0)
@@ -135,22 +159,46 @@ void knetfilter::addRule() {
 	      state_modules = "state"; 
 	      state_definition = "--state";
 	    }
-	  if (dport.length()==0)
+	  if (strcmp("ecn",hasEcn)==0)
 	    {
-	      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	      addp2 << "iptables" << ruleaction << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-	    }
-	  else
-	    {
-	      if (sport.length()==0)
+	      if (dport.length()==0)
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		  addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  addp2 << "iptables" << ruleaction << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
 		}
 	      else
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		  addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  if (sport.length()==0)
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}
+	    }
+	  else
+	    {
+	      if (dport.length()==0)
+		{
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  addp2 << "iptables" << ruleaction << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		}
+	      else
+		{
+		  if (sport.length()==0)
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      addp2 << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
 		}
 	    }
 	}
@@ -243,22 +291,43 @@ void knetfilter::addRule_tcp() {
     else {
       if (strcmp("nostate",stateChoice)==0)
 	{
-	  if (dport.length()==0)
+	  if (strcmp("ecn",hasEcn)==0)
 	    {
-	      addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
-	    }
-	  else
-	    {
-	      if (sport.length()==0)	
+	      if (dport.length()==0)
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		}
 	      else
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  if (sport.length()==0)	
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}      
+	    }
+	  else
+	    {
+	      if (dport.length()==0)
+		{
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		}
-	    }      
-	}
+	      else
+		{
+		  if (sport.length()==0)	
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}      
+	    }
+	}      
       else
 	{
 	  if (strcmp("unclean",stateChoice)==0)
@@ -272,24 +341,45 @@ void knetfilter::addRule_tcp() {
 	      state_modules = "state"; 
 	      state_definition = "--state";
 	    }
-	  if (dport.length()==0)
+	  if (strcmp("ecn",hasEcn)==0)
 	    {
-	      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
-	    }
-	  else
-	    {
-	      if (sport.length()==0)	
+	      if (dport.length()==0)
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		}
 	      else
 		{
-		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		  if (sport.length()==0)	
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
 		}
-	    }      	  
-	}	
+	    }
+	  else
+	    {
+	      if (dport.length()==0)
+		{
+		  addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		}
+	      else
+		{
+		  if (sport.length()==0)	
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		    }
+		  else
+		    {
+		      addp << "iptables" << ruleaction << chainChoice << rulepos << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		}      	  
+	    }	
+	} 
     };
-      
+
     bool success=addp.start();
     if (success)
       statusbar->message(i18n("Running..."), 2000);
@@ -590,7 +680,7 @@ void knetfilter::delRule() {
     if(rulepos.length()!=0)
       {
 	delp << "iptables" << "-D" << chainChoice << rulepos;
-	delp2;	  
+	delp2 << "iptables" << "-v";	  
       }
     else
       {
@@ -607,24 +697,50 @@ void knetfilter::delRule() {
 	  QMessageBox::critical(0, "Error",
 				"Not a valid netmask address.\n");
 	else {
+	  QMessageBox::critical(0, "Deprecated",
+				"This way to delete rules is deprecated.\n It is better to delete rules\n just inserting the rule position,\n then clicking on the 'Stop' (X) button)\n");
 	  if (strcmp("nostate",stateChoice)==0)
 	    {
-	      if (dport.length()==0)
+	      if (strcmp("ecn",hasEcn)==0)
 		{
-		  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		  delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		}
-	      else
-		{
-		  if (sport.length()==0)
+		  if (dport.length()==0)
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		      delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
 		    }
 		  else
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		      delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      if (sport.length()==0)
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		    }
+		}	      
+	      else
+		{
+		  if (dport.length()==0)
+		    {
+		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      if (sport.length()==0)
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
 		    }
 		}
 	    }
@@ -641,22 +757,46 @@ void knetfilter::delRule() {
 		  state_modules = "state"; 
 		  state_definition = "--state";
 		}
-	      if (dport.length()==0)
+	      if (strcmp("ecn",hasEcn)==0)
 		{
-		  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		  delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		}
-	      else
-		{
-		  if (sport.length()==0)
+		  if (dport.length()==0)
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		      delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
 		    }
 		  else
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		      delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      if (sport.length()==0)
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		    }
+		}
+	      else
+		{
+		  if (dport.length()==0)
+		    {
+		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		    }
+		  else
+		    {
+		      if (sport.length()==0)
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			  delp2 << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "udp" << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
 		    }
 		}
 	    }
@@ -746,23 +886,46 @@ void knetfilter::delRule_tcp() {
 	  QMessageBox::critical(0, "Error",
 				"Not a valid netmask address.\n");
 	else {
+	  QMessageBox::critical(0, "Deprecated",
+				"This way to delete rules is deprecated.\n It is better to delete rules\n just inserting the rule position,\n then clicking on the 'Stop' (X) button)\n");
 	  if (strcmp("nostate",stateChoice)==0)
 	    {
-	      if (dport.length()==0)
+	      if (strcmp("ecn",hasEcn)==0)
 		{
-		  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
-		}
-	      else
-		{
-		  if (sport.length()==0)	
+		  if (dport.length()==0)
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		      delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		    }
 		  else
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+		      if (sport.length()==0)	
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		    }      
+		}
+	      else
+		{
+		  if (dport.length()==0)
+		    {
+		      delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		    }
-		}      
+		  else
+		    {
+		      if (sport.length()==0)	
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		    }      
+		}
 	    }
 	  else
 	    {
@@ -777,21 +940,42 @@ void knetfilter::delRule_tcp() {
 		  state_modules = "state"; 
 		  state_definition = "--state";
 		}
-	      if (dport.length()==0)
-		{
-		  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+	      if (strcmp("ecn",hasEcn)==0)
+		{	      
+		   if (dport.length()==0)
+		     {
+		       delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		     }
+		   else
+		     {
+		       if (sport.length()==0)	
+			 {
+			   delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+			 }
+		       else
+			 {
+			   delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-m" << hasEcn << ecnflagChoice << ecnParam << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			 }
+		     }      
 		}
 	      else
 		{
-		  if (sport.length()==0)	
+		  if (dport.length()==0)
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
 		    }
 		  else
 		    {
-		      delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
-		    }
-		}      
+		      if (sport.length()==0)	
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice; 
+			}
+		      else
+			{
+			  delp << "iptables" << "-D" << chainChoice << "-m" << state_modules << state_definition << stateChoice << "-p" << "tcp" << flagChoice << "--sport" << sport << "--dport" << dport << "-s" << extranet << "-d" << network << "-j" << policyChoice;
+			}
+		    }      
+		}
 	    }
 	}
       };
@@ -878,6 +1062,8 @@ void knetfilter::delRule_udp() {
 	  QMessageBox::critical(0, "Error",
 				"Not a valid netmask address.\n");
 	else {
+	  QMessageBox::critical(0, "Deprecated",
+				"This way to delete rules is deprecated.\n It is better to delete rules\n just inserting the rule position,\n then clicking on the 'Stop' (X) button)\n");
 	  if (strcmp("nostate",stateChoice)==0)
 	    {
 	      if (dport.length()==0)
@@ -1009,6 +1195,8 @@ void knetfilter::delRule_icmp() {
 	  QMessageBox::critical(0, "Error",
 				"Not a valid netmask address.\n");
 	else {
+	  QMessageBox::critical(0, "Deprecated",
+				"This way to delete rules is deprecated.\n It is better to delete rules\n just inserting the rule position,\n then clicking on the 'Stop' (X) button)\n");
 	  if (strcmp("nostate",stateChoice)==0)
 	    {
 	      delp3 << "iptables" << "-D" << chainChoice << "-p" << "icmp" << "--icmp-type" << type << "-s" << extranet << "-d" << network << "-j" << policyChoice;
@@ -1100,6 +1288,7 @@ void knetfilter::saveAll() {
   FILE *restore5;
   FILE *restore6;
 
+
   cfgfile = fopen("/etc/iptables.cfg", "r");
   saver1 = fopen ("/bin/iptables-save", "r");
   saver2 = fopen ("/sbin/iptables-save", "r");
@@ -1116,26 +1305,16 @@ void knetfilter::saveAll() {
 
   if ( saver1==NULL && saver2==NULL && saver3==NULL && saver4==NULL && saver5==NULL && saver6==NULL || restore1==NULL && restore2==NULL && restore3==NULL && restore4==NULL && restore5==NULL && restore6==NULL )
     {
-      QMessageBox::information(this, "Warning",
-			      "Couldn't locate iptables-save binary from iptables-1.2.1a or newer.\n"
-			      "For now I will use my own save function, but, please, consider\n"
-			      "to upgrade your iptables as soon, enabling it's own\n"
-			      "iptables-save and iptables-restore command lines. (SEE iptables README)."); 
-
-      save << "kiptables-save";
+      save << "kiptables-save" << "oldfnct";
     }
   else
     {
       if ( cfgfile != NULL)
 	{
 	  remove("/etc/iptables.cfg");
-	}
-      save  << "kiptables-save" << "iptorig";  
-    } 
-
-  // to be removed when iptables-save will work
-  // save << "kiptables-save";
-
+	}      
+      save << "kiptables-save" << "iptorig";
+    }
   bool success=save.start();
 
   if (success)
@@ -1165,82 +1344,28 @@ void knetfilter::loadAll() {
   
 
   FILE *cfgfile_2;
-  FILE *saver1_2;
-  FILE *saver2_2;
-  FILE *saver3_2;
-  FILE *saver4_2;
-  FILE *saver5_2;
-  FILE *saver6_2;
-  FILE *restore1_2;
-  FILE *restore2_2;
-  FILE *restore3_2;
-  FILE *restore4_2;
-  FILE *restore5_2;
-  FILE *restore6_2;
-
   cfgfile_2 = fopen("/etc/iptables.cfg", "r");
-  saver1_2 = fopen ("/bin/iptables-save", "r");
-  saver2_2 = fopen ("/sbin/iptables-save", "r");
-  saver3_2 = fopen ("/usr/bin/iptables-save", "r");
-  saver4_2 = fopen ("/usr/sbin/iptables-save", "r");
-  saver5_2 = fopen ("/usr/local/bin/iptables-save", "r");
-  saver6_2 = fopen ("/usr/local/sbin/iptables-save", "r");
-  restore1_2 = fopen ("/bin/iptables-restore", "r");
-  restore2_2 = fopen ("/sbin/iptables-restore", "r");
-  restore3_2 = fopen ("/usr/bin/iptables-restore", "r");
-  restore4_2 = fopen ("/usr/sbin/iptables-restore", "r");
-  restore5_2 = fopen ("/usr/local/bin/iptables-restore", "r");
-  restore6_2 = fopen ("/usr/local/sbin/iptables-restore", "r");
 
   if ( cfgfile_2 == NULL )
     {
       QMessageBox::information(this, "Warning",
-			       "It seem that yoh do not have a\n"
-			       "previouslt saved configuration.");
+			       "It seems that you do not have a\n"
+			       "previously saved configuration.");
     }
   else
     {
-      if ( saver1_2==NULL && saver2_2==NULL && saver3_2==NULL && saver4_2==NULL && saver5_2==NULL && saver6_2==NULL || restore1_2==NULL && restore2_2==NULL && restore3_2==NULL && restore4_2==NULL && restore5_2==NULL && restore6_2==NULL )
-	{
-	  QMessageBox::information(this, "Warning",
-				   "Couldn't locate iptables-save binary from iptables-1.2.1a or newer.\n"
-				   "For now I will use my own save function, but, please, consider\n"
-				   "to upgrade your iptables as soon, enabling it's own\n"
-				   "iptables-save and iptables-restore command lines. (SEE iptables README)."); 
-	  load << "kiptables-restore"; 
-	}
-      else
-	{
-	  load << "kiptables-restore"; 
-	  // not needed since kiptables-save script is smarter than i thought
-	  // anyway, i want to advise if users should upgrade
-	  //	  load << "kiptables-restore" << "iptorig"; 
-	}
+      load << "kiptables-restore"; 
     }
 
-  // to be removed when iptables-restore will work
-  // load << "kiptables-restore"; 
 
   bool success=load.start();
 
   if (success)
     statusbar->message(i18n("Saving..."), 2000);
   else
-    statusbar->message(i18n("Couldn't save iptables"), 2000);
+    statusbar->message(i18n("Couldn't restore iptables"), 2000);
 
-  /*  fclose (cfgfile_2);
-  fclose (saver1_2);
-  fclose (saver2_2);
-  fclose (saver3_2);
-  fclose (saver4_2);
-  fclose (saver5_2);
-  fclose (saver6_2);
-  fclose (restore1_2);
-  fclose (restore2_2);
-  fclose (restore3_2);
-  fclose (restore4_2);
-  fclose (restore5_2);
-  fclose (restore6_2); */
+  //  fclose (cfgfile_2);
 };
 
 
