@@ -1,8 +1,8 @@
   /*
 
-  knat v 3.1.1
+  knat v 3.1.3
 
-  Copyright (C) 2002 Luigi Genoni
+  Copyright (C) 2003 Luigi Genoni
   		     venom@sns.it
   */
   
@@ -62,6 +62,9 @@ knetfilter::knetfilter( QWidget *, const char *name )
     mangleactionChoice = "TOS";
     mangletosChoice = "Normal-Service";
     mangleSyn = "-v";
+    mangleecnflagChoice = "-v";
+    hasmangleEcn = "-v";
+    mangleecnParam = "-v";
     nmapopt = "-sT";
     nmapopt_icmp = "-PB";
     logLevel = "0";
@@ -205,7 +208,7 @@ void knetfilter::setupMenuBar() {
   
   useMasq = nat_tables->insertItem(i18n("Masquerade"), 
 				this, SLOT(masqRules()));
-  nat_tables->insertItem(i18n("Redirections"),
+  nat_tables->insertItem(i18n("NAT & Redirections"),
   			        this, SLOT(natRules()));
   nat_tables->insertItem(i18n("Define Nat Chain policy"),
 			        this, SLOT(natpolRules()));
@@ -223,7 +226,7 @@ void knetfilter::setupMenuBar() {
   options->insertItem(i18n("TcpMSS set up"),
 		                this, SLOT(tcpmssRules()));
   options->insertSeparator();
-  options->insertItem(i18n("List Rules, &Masquerading, Mangle entries"),
+  options->insertItem(i18n("List Rules, &NAT, Mangle entries"),
   				this, SLOT(iptablesRules()));
   options->insertItem(i18n("List &Routes, Ipaddrs, Route Cache"),
   				this, SLOT(routeRules()));
